@@ -4,6 +4,7 @@ import json
 import re
 from datetime import datetime
 from math import ceil, log
+from dateutil import parser
 
 
 def is_string(v):
@@ -15,7 +16,7 @@ def is_integer(v):
 
 
 def is_list(v):
-    return isinstance(v, list) and all(isinstance(x, str) for x in v)
+    return isinstance(v, list)
 
 
 def is_json(v):
@@ -45,8 +46,11 @@ def is_epoch_ms(v):
 
 
 def is_iso8601(v):
-    raise datetime.fromisoformat(v)
-
+    try:
+        parser.isoparse(v)
+        return True
+    except Exception:
+        return False
 
 def is_date(v):
     # todo: make this regex more exact, idk what platform is looking for currently
@@ -96,7 +100,7 @@ def is_attachment(v):
 
 
 def is_numeric_list(v):
-    return isinstance(v, list) and all(isinstance(x, int) for x in v)
+    return isinstance(v, list) and all(isinstance(x, (int, float)) for x in v)
 
 
 def is_category(v):
